pub enum StdinPolicy {
Null,
Held,
}Expand description
What capture does with the child’s stdin.
Variants
Null
The child reads /dev/null and sees EOF immediately.
Held
The child’s stdin is a pipe whose local writer is held open for the whole capture and dropped when the child has exited. The child sees an open stdin with no data — never an early EOF.